@@ -8,6 +8,7 @@ class Topographic(DataSourceOutput):
 
     __slots__ = ()
     _expected_dimensions = ("x", "y")
+    _expected_data_vars = ("data",)
 
     @classmethod
     def model_validation(cls, v):
@@ -15,4 +16,6 @@ class Topographic(DataSourceOutput):
 
         v.check_nan_and_inf(data=v.data)
 
+        v.check_data_var_dim(v.data, ("example", "x_index", "y_index"))
+
         return v
